@@ -447,9 +447,16 @@ class PlaywrightState(LibraryComponent):
 
         ``httpCredentials`` Credentials for
         [https://developer.mozilla.org/en-US/docs/Web/HTTP/Authentication|HTTP authentication].
-        - example: ``{'username': 'admin', 'password': '123456'}``
+        - example: ``{'username': '$username', 'password': '$pwd'}``
         - ``username``
         - ``password``
+        Direct usage of username and password is not recommended, but is possible. If username and password
+        is directly used, it can leak secret information to Robot Framework output files. Instead the username
+        and password values can be prefixed with ``$`` or ``%``.  Then keyword will internally resolve the
+        values and secrets are not leaked to Robot Framework output files. The ``$`` prefix will resolve Robot
+        Framework variable and ``%`` will resolve environment variable. If
+        [https://marketsquare.github.io/robotframework-browser/Browser.html#Importing|enable_playwright_debug]
+        is enabled, all secrets are written as plain text in Playwright debugs logs.
 
         ``colorScheme`` Emulates 'prefers-colors-scheme'
         media feature, supported values are 'light', 'dark', 'no-preference'.
@@ -515,11 +522,16 @@ class PlaywrightState(LibraryComponent):
         params = locals_to_params(locals())
         params = self._set_video_path(params)
         params = self._set_video_size_to_int(params)
+        if "httpCredentials" in params and params["httpCredentials"] is not None:
+            self.resolve_secret(
+                httpCredentials, params.get("httpCredentials"), "httpCredentials"
+            )
         params = convert_typed_dict(self.new_context.__annotations__, params)
         if not videosPath:
             params.pop("videoSize", None)
+        masked_params = self._mask_credentials(params.copy())
         options = json.dumps(params, default=str)
-        logger.info(options)
+        logger.info(json.dumps(masked_params, default=str))
         with self.playwright.grpc_channel() as stub:
             response = stub.NewContext(
                 Request().Context(
@@ -528,7 +540,10 @@ class PlaywrightState(LibraryComponent):
                     defaultTimeout=int(self.timeout),
                 )
             )
-        logger.info(response.log)
+        log_msg, json_data = response.log.split("options:")
+        log_msg = f"{log_msg} options:"
+        json_data = self._mask_credentials(json.loads(json_data))
+        logger.info(f"{log_msg}\n{json.dumps(json_data)}")
         if response.newBrowser:
             logger.info(
                 "No browser was open. New browser was automatically opened "
@@ -537,6 +552,11 @@ class PlaywrightState(LibraryComponent):
         self.context_cache.add(response.id, self._get_video_size(params))
         return response.id
 
+    def _mask_credentials(self, data: dict):
+        if "httpCredentials" in data:
+            data["httpCredentials"] = "XXX"
+        return data
+
     def _set_video_path(self, params: dict) -> dict:
         video_path = params.get("videosPath")
         record_video = params.get("recordVideo", {})
